import PageContent from '@/components/PageContent';
import { useParams } from '@umijs/max';
import { Table } from 'antd';
import styles from './detail.less';
import PageTitle from '@/components/PageTitle';
const {
  DeviceCode,
  DeviceName,
  Reason,
  PlanTime,
  RepairType,
  IsPlan,
  DifficultyLevel,
  AcceptanceStatus,
  EvaluationScore,
  Operators,
  RepairTime,
  Desc,
  MaterialConsumption,
  AcceptorUser,
  AcceptanceTime,
  Level,
  AcceptanceOpinion,
  Note,
  Files = [],
} = JSON.parse(localStorage.repair || '{}');

export default function DeviceMaintainDetail() {
  const { projectId, type } = useParams();

  const columns = [
    {
      title: type == 1 ? '维修资料' : '保养资料',
      dataIndex: 'Name',
      render: (text, item) => {
        return <PreviewFile name={item.Name} src={item.Url} />;
      },
    },
    {
      title: '创建时间',
      dataIndex: 'CreatedTime',
      render: (text) => {
        return text ? moment(text).format('YYYY年MM月DD日  HH:mm:ss') : null;
      },
    },
    {
      title: '操作',
      width: '20%',
      render: (record) => (
        <Fragment>
          {this.showJurisdiction('func-01-ops-1-2-3-01') && (
            <>
              &nbsp;&nbsp;
              <a
                style={{ color: '#7BFFFB' }}
                onClick={() => this.checkFile(record)}
                download
              >
                下载
              </a>
            </>
          )}
        </Fragment>
      ),
    },
  ];

  function getUser(params) {
    let arr = [];
    if (!params) {
      return;
    } else {
      return (arr = params
        .map((item) => {
          return item.Operator?.CName;
        })
        .join(','));
    }
  }
  const getStatus = (time, acStatus) => {
    if (time && acStatus == 0) return '不通过';
    if (time && acStatus == 2) return '通过';
    return '';
  };

  return (
    <PageContent >
      <PageTitle>设备维修</PageTitle>
      <div className={styles.detailBox}>
        <span>
          <label>设备位号:</label>
          {DeviceCode}
        </span>
        <span>
          <label>维修人:</label>
          {getUser(Operators)}
        </span>
        <span>
          <label>设备名称:</label>
          {DeviceName}
        </span>
        <span>
          <label>维修日期:</label>
          {RepairTime}
        </span>
        <span>
          <label>维修原因:</label>
          {Reason}
        </span>
        <span>
          <label>维修内容简述:</label>
          {Desc}
        </span>

        <span>
          <label>计划日期:</label>
          {PlanTime}
        </span>
        <span>
          <label>物料消耗:</label>
          {MaterialConsumption}
        </span>

        <span>
          <label>维修方式:</label>
          {RepairType}
        </span>
        <span>
          <label>验收人:</label>
          {AcceptorUser?.CName}
        </span>

        <span>
          <label>是否计划内:</label>
          {String(IsPlan) == 0 ? '否' : '是'}
        </span>
        <span>
          <label>验收状态:</label>
          {getStatus(AcceptanceTime, AcceptanceStatus)}
        </span>

        <span>
          <label>难度级别:</label>
          {DifficultyLevel}
        </span>
        <span>
          <label>级别:</label>
          {Level}
        </span>
        <span>
          <label>维修状态:</label>
          {AcceptanceStatus}
        </span>
        <span>
          <label>验收意见:</label>
          {AcceptanceOpinion}
        </span>

        <span>
          <label>评估分数:</label>
          {EvaluationScore * 100}
        </span>
        <span>
          <label>保养备注:</label>
          {Note?.split('|').map((item) => (
            <div>{item}</div>
          ))}
        </span>
      </div>
      <Table
        style={{ marginTop: '0.1rem' }}
        dataSource={Files}
        columns={columns}
        pagination={false}
      />
    </PageContent>
  );
}
